==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "აუცილებელი",
    "Today" : "დღეს",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Tasks" : "დავალებები",
    "New List" : "ახალი სია",
    "Cancel" : "უარყოფა",
    "Save" : "შენახვა",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "can edit" : "შეუძლია შეცვლა",
    "Edit" : "რედაქტირება",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "წაშლა",
    "Unshare" : "გაზიარების შეწყვეტა",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Change sort order" : "განლაგების შეცვლა",
    "Start date" : "დაწყების თარიღი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Last modified" : "ბოლო ცვლილება",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Manually" : "ხელით",
    "Task is completed" : "დავალება დასრულებულია",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
    "Tomorrow" : "ხვალ",
    "Set start date" : "საწყისი დრო",
    "Set due date" : "განპირობებულია თარიღისთვის",
    "All day" : "მთელი დღე",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-tasks-0.14.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "აუცილებელი",
    "Today" : "დღეს",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Tasks" : "დავალებები",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Edit" : "რედაქტირება",
    "Delete" : "წაშლა",
    "Unshare" : "გაზიარების შეწყვეტა",
    "Cancel" : "უარყოფა",
    "Save" : "შენახვა",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Change sort order" : "განლაგების შეცვლა",
    "Start date" : "დაწყების თარიღი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Last modified" : "ბოლო ცვლილება",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Manually" : "ხელით",
    "Task is completed" : "დავალება დასრულებულია",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
    "Tomorrow" : "ხვალ",
    "New List" : "ახალი სია",
    "All day" : "მთელი დღე",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "Set start date" : "საწყისი დრო",
    "Set due date" : "განპირობებულია თარიღისთვის"
},
"nplurals=2; plural=(n!=1);");
